﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO.Ports;
using RGBController2.Boards;
using System.ComponentModel;

namespace RGBController2.ViewModels.Tabs
{
    public class ArduinoTab : Tab, INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;
        private enum LightingModes
        {
            StaticMode = 0,
            AnimationMode,
            QuakeMode
        }

        private ArduinoBoard _arduinoBoard;

        private string[] _availablePorts;
        public string[] AvailablePorts
        {
            get { return _availablePorts; }
            set { _availablePorts = value; }
        }

        private string _conntectionStatus;
        public string ConnectionStatus
        {
            get { return _conntectionStatus; }
            set { _conntectionStatus = value; }
        }

        private string _selectedPort;
        public string SelectedPort
        {
            get { return _selectedPort; }
            set 
            {
                if (value != _selectedPort)
                {
                    _selectedPort = value;
                    // Connect to the port here
                    _arduinoBoard = new ArduinoBoard(_selectedPort);
                    if (_arduinoBoard.Conected)
                        ConnectionStatus = "Device Connected";
                    else
                        ConnectionStatus = "Device Disconnected";
                    OnPropertyChanged(nameof(ConnectionStatus));
                }
            }
        }

        private LightingModes _lightingMode;
        public int LightingMode
        {
            get { return (int)_lightingMode; }
            set { _lightingMode = (LightingModes) value; }
        }
             
        public ArduinoTab(string name)
        {
            Name = name;
            ConnectionStatus = "Device Disconnected";
            _selectedPort = "";

            // Get a list of the available com ports
            string[] ports = SerialPort.GetPortNames();
            _availablePorts = ports;
        }

        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
